package com.wechi.adweb.bridge.google.ads.common;

import com.google.ads.googleads.v18.resources.GroupPlacementView;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author wfansh
 */
public class PlacementUtils {
    private static final Pattern MOBILE_APP_DISPLAY_NAME_PATTERN =
            Pattern.compile("Mobile App:(.+)\\(");

    public static String format(GroupPlacementView view) {
        return switch (view.getPlacementType()) {
                // Website domain name.
            case WEBSITE -> view.getDisplayName();
            case MOBILE_APPLICATION, MOBILE_APP_CATEGORY ->
                    formatMobileApp(view.getPlacement(), view.getDisplayName());
            case GOOGLE_PRODUCTS -> "Google";
            case YOUTUBE_CHANNEL, YOUTUBE_VIDEO -> "YouTube - " + view.getDisplayName();
            default -> "UNKNOWN";
        };
    }

    /**
     * @param placement Represented as '1-683520774' for iOS, or '2-reas.gem.file' for Android.
     * @param displayName 'Mobile App: Roya TV (iTunes App Store), by Watan Broadcasting Satellite'
     *     for iOS, or 'Mobile App: Hidden Gem (Google Play), by Empiraft' for Android.
     */
    private static String formatMobileApp(String placement, String displayName) {
        Matcher matcher = MOBILE_APP_DISPLAY_NAME_PATTERN.matcher(displayName);
        if (!matcher.find()) {
            // Returns original display name if not matched.
            return displayName;
        }
        String appName = matcher.group(1).trim();
        String platform =
                switch (placement.charAt(0)) {
                    case '1' -> "iOS";
                    case '2' -> "Android";
                    default -> "other";
                };

        return String.format("%s: %s", platform, appName);
    }
}
