package com.wechi.adweb.bridge.google.ads.service;

import com.google.ads.googleads.lib.GoogleAdsClient;
import com.google.auth.Credentials;
import com.google.auth.oauth2.UserCredentials;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * @author wfansh
 */
@Configuration
public class GoogleAdsConfig {
    @Value("${api.googleads.clientId}")
    private String clientId;

    @Value("${api.googleads.clientSecret}")
    private String clientSecret;

    @Value("${api.googleads.refreshToken}")
    private String refreshToken;

    @Value("${api.googleads.developerToken}")
    private String developerToken;

    @Value("${api.googleads.loginCustomerId}")
    private Long loginCustomerId;

    @Bean
    public GoogleAdsClient defaultGoogleAdsClient() {
        Credentials credentials =
                UserCredentials.newBuilder()
                        .setClientId(clientId)
                        .setClientSecret(clientSecret)
                        .setRefreshToken(refreshToken)
                        .build();
        return GoogleAdsClient.newBuilder()
                .setCredentials(credentials)
                .setDeveloperToken(developerToken)
                .setLoginCustomerId(loginCustomerId)
                .build();
    }

    /**
     * Creates a {@link GoogleAdsClient} using a customer-provided refresh token.
     *
     * <p>This is used when the customer's Google Ads account is not managed under the AdVich MCC.
     */
    public GoogleAdsClient buildGoogleAdsClient(String refreshToken) {
        Credentials credentials =
                UserCredentials.newBuilder()
                        .setClientId(clientId)
                        .setClientSecret(clientSecret)
                        .setRefreshToken(refreshToken)
                        .build();
        return GoogleAdsClient.newBuilder()
                .setCredentials(credentials)
                .setDeveloperToken(developerToken)
                .build();
    }
}
