package com.wechi.adweb.bridge.matomo.service;

import com.google.common.io.Resources;

import lombok.extern.slf4j.Slf4j;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.nio.charset.StandardCharsets;

import javax.annotation.PostConstruct;

/**
 * @author wfansh
 */
@Slf4j
@Service
public class MatomoTagService {

    @Value("${matomo.url}")
    private String matomoUrl;

    @Value("${matomo.trackingCode.template}")
    private String trackingCodeTemplate;

    private String trackingCodeFormat;

    @PostConstruct
    private void init() throws IOException {
        trackingCodeFormat =
                Resources.toString(
                        this.getClass().getClassLoader().getResource(trackingCodeTemplate),
                        StandardCharsets.UTF_8);
    }

    public String getTrackingCode(String siteId) {
        try {
            return String.format(trackingCodeFormat, new URL(matomoUrl).getHost(), siteId);
        } catch (MalformedURLException e) {
            log.error("Invalid URL", e);
            return null;
        }
    }
}
