package com.wechi.adweb.bridge.google.ads;

import com.wechi.adweb.bridge.exception.DataException;
import com.wechi.adweb.bridge.google.ads.dto.CustomerStatsDTO;
import com.wechi.adweb.bridge.google.ads.dto.MetricsDTO;
import com.wechi.adweb.bridge.google.ads.dto.ReportRequestDTO;
import com.wechi.adweb.bridge.google.ads.service.GoogleAdsService;
import com.wechi.adweb.bridge.util.JsonUtils;

import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

import java.util.Map;

/**
 * @author wfansh
 */
@SpringBootTest
public class GoogleAdsServiceTest {

    @Autowired private GoogleAdsService googleAdsService;

    private final String customerId = "6665891131"; // 泓瑞纺织机械-sutexmach.com

    @Test
    void testGetCustomerStats() throws DataException {
        ReportRequestDTO reportRequest = new ReportRequestDTO();
        reportRequest.setCustomerId("7836935572"); // wfansh@google.com
        // Uses customer-provided refresh token.
        // This is used when the customer's Google Ads account is not managed under the AdVich MCC.
        reportRequest.setRefreshToken(
                "1//04v5cFDkutCvdCgYIARAAGAQSNwF-L9Ir3SCqBes_BQSSfwLaQ-8U5R-bloZHLczJ37ekxwuwgXtFKngjPBSYBqnov_O7gpKydEE");

        CustomerStatsDTO customerStats = googleAdsService.getCustomerStats(reportRequest);
        System.out.println(JsonUtils.toJson(customerStats));
    }

    @Test
    void testGetDailyStats() throws DataException {
        ReportRequestDTO reportRequest = new ReportRequestDTO();
        reportRequest.setCustomerId(customerId);
        reportRequest.setStartDate("2024-12-01");
        reportRequest.setEndDate("2024-12-06");
        reportRequest.setLimit(100);

        Map<String, MetricsDTO> dailyStats = googleAdsService.getDailyStats(reportRequest);
        System.out.println(JsonUtils.toJson(dailyStats));
    }

    @Test
    void testGetKeywordStats() throws DataException {
        ReportRequestDTO reportRequest = new ReportRequestDTO();
        reportRequest.setCustomerId(customerId);
        reportRequest.setStartDate("2024-01-01");
        reportRequest.setEndDate("2024-12-06");
        reportRequest.setLimit(100);

        Map<String, MetricsDTO> dailyStats = googleAdsService.getKeywordStats(reportRequest);
        System.out.println(JsonUtils.toJson(dailyStats));
    }
}
